<!--
{% comment %}
Copyright 2018-2022 Elyra Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
{% endcomment %}
-->

# Contributing

Welcome to Elyra! If you are interested in contributing to the [Elyra code repo](README.md)
then checkout the [Contributor's Guide](https://github.com/elyra-ai/community/blob/master/contributing.md) and 
the [Code of Conduct](https://github.com/elyra-ai/community/blob/master/code-of-conduct.md). 

The [Elyra community repo](https://github.com/elyra-ai/community) contains information on how the community
is organized and other information that is pertinent to contributing.

### Getting Started

It's encouraged that you look under the [Issues](https://github.com/elyra-ai/elyra/issues) tab for contribution opportunites.
For those new to the project, we suggest looking under:

- Issues tagged as [Good First Issue](https://github.com/elyra-ai/elyra/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc+label%3A%22good+first+issue%22)
- Issues tagged as [Help Wanted](https://github.com/elyra-ai/elyra/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc+label%3A%22help+wanted%22 )
- Issues tagged as [Good First Project](https://github.com/elyra-ai/elyra/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+project%22)

If you are planning to contribute to source code, the [development workflow](https://elyra.readthedocs.io/en/latest/developer_guide/development-workflow.html) can help you set up and 
build Elyra in a development environment.
